==> tuia-explore-center-api-0.0.1-20190530.113355-37-sources.jar: cn/tuia/explore/center/api/dto/general/SystemMessage.java <==
package cn.tuia.explore.center.api.dto.general;

/**
 * @author ElinZhou zhoufeng@duiba.com.cn
 * @version $Id: SystemMessage.java , v 0.1 2019-05-29 09:33 ElinZhou Exp $
 */
public class SystemMessage extends AbstractMessageContent {
    private static final long serialVersionUID = 777341602843549033L;

    private long systemId;

    private transient String title;

    private transient String headImage;

    private transient String content;

    private transient String jumpUrl;

    @Override
    protected String title() {
        return title;
    }

    @Override
    protected String content() {
        return content;
    }

    @Override
    protected String icon() {
        return headImage;
    }

    @Override
    protected String jumpUrl() {
        return super.jumpUrl();
    }

    public long getSystemId() {
        return systemId;
    }

    public void setSystemId(long systemId) {
        this.systemId = systemId;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getHeadImage() {
        return headImage;
    }

    public void setHeadImage(String headImage) {
        this.headImage = headImage;
    }

    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }

    public String getJumpUrl() {
        return jumpUrl;
    }

    public void setJumpUrl(String jumpUrl) {
        this.jumpUrl = jumpUrl;
    }
}

==> tuia-explore-center-api-0.4.0-20190702.064846-13-sources.jar: cn/tuia/explore/center/api/dto/general/SystemMessage.java <==
package cn.tuia.explore.center.api.dto.general;

/**
 * @author ElinZhou zhoufeng@duiba.com.cn
 * @version $Id: SystemMessage.java , v 0.1 2019-05-29 09:33 ElinZhou Exp $
 */
public class SystemMessage extends AbstractMessageContent {
    private static final long serialVersionUID = 777341602843549033L;

    private long systemId;

    private transient String title;

    private transient String headImage;

    private transient String content;

    private transient String jumpPath;

    private transient String jumpUrl;

    @Override
    protected String title() {
        return title;
    }

    @Override
    protected String content() {
        return content;
    }

    @Override
    protected String icon() {
        return headImage;
    }

    @Override
    public String jumpPath() {
        return jumpPath;
    }

    @Override
    public String jumpUrl() {
        return jumpUrl;
    }

    public long getSystemId() {
        return systemId;
    }

    public void setSystemId(long systemId) {
        this.systemId = systemId;
    }

    public String getTitle() {
        return title;
    }

    public void setTitle(String title) {
        this.title = title;
    }

    public String getHeadImage() {
        return headImage;
    }

    public void setHeadImage(String headImage) {
        this.headImage = headImage;
    }

    public String getContent() {
        return content;
    }

    public void setContent(String content) {
        this.content = content;
    }

    public String getJumpUrl() {
        return jumpUrl;
    }

    public void setJumpUrl(String jumpUrl) {
        this.jumpUrl = jumpUrl;
    }

    public String getJumpPath() {
        return jumpPath;
    }

    public void setJumpPath(String jumpPath) {
        this.jumpPath = jumpPath;
    }
}
